=======
Credits
=======


Current maintainers
-------------------
* Simon Birrer <sibirrer@gmail.com> `sibirrer <https://github.com/sibirrer/>`_
* Anowar Shajib `ajshajib <https://github.com/ajshajib/>`_
* Daniel Gilman `dangilman <https://github.com/dangilman/>`_

Contact the lenstronomy developers via `email <lenstronomy-dev@googlegroups.com>`_ if you have questions.



Contributors (alphabetic)
-------------------------

* Jelle Aalbers `JelleAalbers <https://github.com/JelleAalbers>`_
* Joel Akeret `jakeret <https://github.com/jakeret/>`_
* Adam Amara `aamara <https://github.com/aamara/>`_
* Vikram Bhamre `vikramb1 <https://github.com/vikramb1/>`_
* Xuheng Ding `dartoon <https://github.com/dartoon/>`_
* Sydney Erickson `smericks <https://github.com/smericks/>`_
* Andreas Filipp `andreasfilipp <https://github.com/andreasfilipp/>`_
* Pierre Fleury `pierrefleury <https://github.com/pierrefleury/>`_
* Kevin Fusshoeller
* Aymeric Galan `aymgal <https://github.com/aymgal/>`_
* Matthew R. Gomer `mattgomer <https://github.com/mattgomer>`_
* Natalie B. Hogg `nataliehogg <https://github.com/nataliehogg>`_
* Tyler Hughes
* Daniel Johnson `DanJohnson98 <https://github.com/DanJohnson98>`_
* Felix A. Kuhn
* Johannes U. Lange `johannesulf <https://github.com/johannesulf>`_
* Zhiyuan Ma `Jerry-Ma <https://github.com/Jerry-Ma/>`_
* Felix Mayor
* Martin Millon `martin-millon <https://github.com/martin-millon/>`_
* Robert Morgan `rmorgan10 <https://github.com/rmorgan10/>`_
* Anna Nierenberg `amn3142 <https://github.com/amn3142/>`_
* Brian Nord `bnord <https://github.com/bnord/>`_
* Jackson O'Donnell `jhod0 <https://github.com/jhod0/>`_
* Maverick S. H. Oh `Maverick-Oh <https://github.com/Maverick-Oh>`_
* Giulia Pagano
* Ji Won Park `jiwoncpark <https://github.com/jiwoncpark/>`_
* Thomas Schmidt `Thomas-01 <https://github.com/Thomas-01/>`_
* Dominique Sluse
* Luca Teodori `lucateo <https://github.com/lucateo/>`_
* Nicolas Tessore `ntessore <https://github.com/ntessore/>`_
* Madison Ueland `mueland <https://github.com/mueland/>`_
* Lyne Van de Vyvere `LyneVdV <https://github.com/LyneVdV/>`_
* Sebastian Wagner-Carena `swagnercarena <https://github.com/swagnercarena>`_
* Cyril Welschen
* Ewoud Wempe `ewoudwempe <https://github.com/ewoudwempe/>`_
* Lilan Yang `ylilan <https://github.com/ylilan/>`_
* Nan Zhang `nanz6 <https://github.com/nanz6/>`_





Past development lead
---------------------

The initial source code of lenstronomy was developed by Simon Birrer (`sibirrer <https://github.com/sibirrer/>`_)
in 2014-2018 and made public in 2018. From 2018-2022 the development of lenstronomy was hosted on Simon Birrer's
repository with increased contributions from many people.
The lenstronomy development moved to the `project repository <https://github.com/lenstronomy/>`_ in 2022.


Lenstronomy logo
----------------
The lenstronomy logo was designed by Zoe Alexander `zoe-blyss <https://github.com/zoe-blyss>`_.
